package gov.usgs.earthquake.nshmp.www;

import static com.google.common.base.CaseFormat.LOWER_CAMEL;
import static com.google.common.base.CaseFormat.UPPER_UNDERSCORE;

import com.google.gson.Gson;
import com.google.gson.GsonBuilder;

public class Utils {
  public static final Gson GSON;

  static {
    GSON = new GsonBuilder()
        .disableHtmlEscaping()
        .serializeNulls()
        .setPrettyPrinting()
        .create();
  }

  public enum Key {
    DISTANCE,
    ID,
    IMT,
    GMM,
    GPSDATASET,
    GROUP,
    LABEL,
    LATITUDE,
    LONGITUDE,
    M_MIN,
    M_MAX,
    MODEL,
    NAME,
    R_MAX,
    R_MIN,
    STEP,
    Z1P0,
    Z2P5;

    @Override
    public String toString() {
      return UPPER_UNDERSCORE.to(LOWER_CAMEL, name());
    }
  }

  public static String handleError(
      Throwable e,
      String name,
      String url) {
    var msg = e.getMessage() + " (see logs)";
    var svcResponse = ResponseBody.error()
        .name(name)
        .url(url)
        .metadata(new ResponseMetadata(WsVersion.appVersions()))
        .request(msg)
        .response(url)
        .build();
    e.printStackTrace();
    return GSON.toJson(svcResponse);
  }
}
