package gov.usgs.earthquake.nshmp.www.gmm;

import java.util.ArrayList;
import java.util.List;

/*
 * XY data sequences serialization object.
 *
 * @author U.S. Geological Survey
 */
@SuppressWarnings("unused")
class XyDataGroup<T, U> {

  private final String label;
  private final String xLabel;
  private final String yLabel;
  private final List<Series<T, U>> data;

  private XyDataGroup(String label, String xLabel, String yLabel) {
    this.label = label;
    this.xLabel = xLabel;
    this.yLabel = yLabel;
    this.data = new ArrayList<>();
  }

  /* Create a data group. */
  static <T, U> XyDataGroup<T, U> create(String name, String xLabel, String yLabel) {
    return new XyDataGroup<T, U>(name, xLabel, yLabel);
  }

  /* Add a data sequence */
  XyDataGroup<T, U> add(String id, String name, T data, List<U> tree) {
    this.data.add(new Series<>(id, name, data, tree));
    return this;
  }

  static class Series<T, U> {

    private final String id;
    private final String label;
    private final T data;
    private final List<U> tree;

    Series(String id, String label, T data, List<U> tree) {
      this.id = id;
      this.label = label;
      this.data = data;
      this.tree = tree;
    }
  }

  static class EpiSeries<T> {

    final String id;
    final T values;
    final T weights;

    EpiSeries(String id, T values, T weights) {
      this.id = id;
      this.values = values;
      this.weights = weights;
    }
  }

}
